searchNodes=[{"doc":"Agency is an abstraction layer above Agent allowing to use any container supporting Access behind and simplifying the client API handling. Agency itself implements Access behaviour, making it possible to embed instances in the middle of Access.keys chains. In a nutshell, Agency backs up the Agent holding a container. All the standard CRUD-like calls are done through containers’ Access implementation, allowing transparent shared access. The set of before_***/1 and after_***/1 functions are introduced, so that the main Agent feature distinguishing it from the standard GenServer holding state—namely, a separation of client and server APIs—is exposed transparently to the consumers. Consider the following example. defmodule MyAgent do use Agency, into: %{} # default def after_get(value) do value + 1 end ... end The above code introduces an Agent backing up Map and exposes the standard CRUD-like functionality. After the value would be got from the server API, it’d be increased by 1 and returned to the consumer. Options use Agency accepts two options: into: Access.t() the container to be used by Agent data: map() | keyword() the static data to be held by the instances One might also pass any struct, or whatever else implementing Access as into: option to be used as an Agent container.","ref":"Agency.html","title":"Agency","type":"behaviour"},{"doc":"The callback that is called from get/1 right after the Agent has returned the value, passing this value as a parameter.","ref":"Agency.html#c:after_get/1","title":"Agency.after_get/1","type":"callback"},{"doc":"The callback that is called from get_and_update/2 right after the Agent has returned the value, passing this value as a parameter.","ref":"Agency.html#c:after_get_and_update/1","title":"Agency.after_get_and_update/1","type":"callback"},{"doc":"The callback that is called from pop/1 right after the Agent has returned the value, passing this value as a parameter.","ref":"Agency.html#c:after_pop/1","title":"Agency.after_pop/1","type":"callback"},{"doc":"The callback that is called from put/2 right after the Agent has returned the value, passing this value as a parameter.","ref":"Agency.html#c:after_put/1","title":"Agency.after_put/1","type":"callback"},{"doc":"The callback that is called from this/0 right after the Agent has returned the value, passing this value as a parameter.","ref":"Agency.html#c:after_this/1","title":"Agency.after_this/1","type":"callback"},{"doc":"The callback that is called from update/2 right after the Agent has returned the value, passing this value as a parameter.","ref":"Agency.html#c:after_update/1","title":"Agency.after_update/1","type":"callback"},{"doc":"Creates an Agent module. If the module is already loaded, this is a no-op.","ref":"Agency.html#agent!/2","title":"Agency.agent!/2","type":"function"},{"doc":"The callback that is called from all the interface methods (but this/0) right before the Agent is to be called. Specific handlers take precedence over this one.","ref":"Agency.html#c:before_all/1","title":"Agency.before_all/1","type":"callback"},{"doc":"The callback that is called from get/1 right before the Agent is to be called, passing key as an argument. It should return a modified key. Note that the key here is always represented a list, even if the single value was passed to the interface function.","ref":"Agency.html#c:before_get/1","title":"Agency.before_get/1","type":"callback"},{"doc":"The callback that is called from get_and_update/2 right before the Agent is to be called, passing key as an argument. It should return a modified key. Note that the key here is always represented a list, even if the single value was passed to the interface function.","ref":"Agency.html#c:before_get_and_update/1","title":"Agency.before_get_and_update/1","type":"callback"},{"doc":"The callback that is called from pop/1 right before the Agent is to be called, passing key as an argument. It should return a modified key. Note that the key here is always represented a list, even if the single value was passed to the interface function.","ref":"Agency.html#c:before_pop/1","title":"Agency.before_pop/1","type":"callback"},{"doc":"The callback that is called from put/2 right before the Agent is to be called, passing key as an argument. It should return a modified key. Note that the key here is always represented a list, even if the single value was passed to the interface function.","ref":"Agency.html#c:before_put/1","title":"Agency.before_put/1","type":"callback"},{"doc":"The callback that is called from update/2 right before the Agent is to be called, passing key as an argument. It should return a modified key. Note that the key here is always represented a list, even if the single value was passed to the interface function.","ref":"Agency.html#c:before_update/1","title":"Agency.before_update/1","type":"callback"},{"doc":"","ref":"Agency.html#t:key/0","title":"Agency.key/0","type":"type"},{"doc":"","ref":"Agency.html#t:keys/0","title":"Agency.keys/0","type":"type"},{"doc":"","ref":"Agency.html#t:keyz/0","title":"Agency.keyz/0","type":"type"},{"doc":"","ref":"Agency.html#t:value/0","title":"Agency.value/0","type":"type"},{"doc":"The Agent backing up the %{} instance.","ref":"TestAgency.html","title":"TestAgency","type":"module"},{"doc":"Returns a thing that might be used in Kernel.***_in function family.","ref":"TestAgency.html#access/0","title":"TestAgency.access/0","type":"function"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor.","ref":"TestAgency.html#child_spec/1","title":"TestAgency.child_spec/1","type":"function"},{"doc":"Get the value for the specific key from the container, backed up by the Agent.","ref":"TestAgency.html#get/2","title":"TestAgency.get/2","type":"function"},{"doc":"Get the value for the specific key from the container, backed up by the Agent, and updates it.","ref":"TestAgency.html#get_and_update/3","title":"TestAgency.get_and_update/3","type":"function"},{"doc":"Pops the value for the specific key in the container, backed up by the Agent.","ref":"TestAgency.html#pop/2","title":"TestAgency.pop/2","type":"function"},{"doc":"Put the value under the specific key to the container, backed up by the Agent.","ref":"TestAgency.html#put/3","title":"TestAgency.put/3","type":"function"},{"doc":"Starts the Agent that backs up the container (defaulted to Map.) The argument passed to the function is ignored.","ref":"TestAgency.html#start_link/1","title":"TestAgency.start_link/1","type":"function"},{"doc":"Returns the whole container, backed up by the Agent.","ref":"TestAgency.html#this/1","title":"TestAgency.this/1","type":"function"},{"doc":"Update the value for the specific key in the container, backed up by the Agent.","ref":"TestAgency.html#update/3","title":"TestAgency.update/3","type":"function"},{"doc":"Agency   One more unnecessary abstraction on top of Agent","ref":"readme.html","title":"Agency","type":"extras"},{"doc":"Agency is an abstraction layer above Agent allowing to use any container supporting Access behind and simplifying the client API handling. Agency itself implements Access behaviour, making it possible to embed instances in the middle of Access.keys chains. In a nutshell, Agency backs up the Agent holding a container. All the standard CRUD-like calls are done through containers’ Access implementation, allowing transparent shared access. The set of after_***/1 functions are introduced, so that the main Agent feature distinguishing it from the standard GenServer holding state—namely, a separation of client and server APIs—is exposed transparently to the consumers.","ref":"readme.html#introduction","title":"Agency - Introduction","type":"extras"},{"doc":"def deps do [ {:agency, &quot;~&gt; 0.1&quot;} ] end","ref":"readme.html#installation","title":"Agency - Installation","type":"extras"},{"doc":"","ref":"readme.html#documentation","title":"Agency - Documentation.","type":"extras"}]